---
name: Feature request
about: Suggest an idea for Locust
title: ''
labels: feature request
assignees: ''

---

<!-- 
No questions here please! If you have a question about how to use Locust read the documentation or ask on slack (https://locustio.slack.com)

You can also ask questions on StackOverflow, https://stackoverflow.com/questions/ask just remember to tag your question with "locust".
-->

### Is your feature request related to a problem? Please describe.
<!-- A clear and concise description of what the problem is. Ex. I'm always frustrated when [...] -->

### Describe the solution you'd like
<!-- A clear and concise description of what you want to happen -->

### Describe alternatives you've considered
<!-- A clear and concise description of any alternative solutions or features you've considered -->

### Additional context
<!-- Add any other context or screenshots about the feature request here -->
